@@ -1,17 +1,34 @@
 """
-Version 0.3.1 (in development)
+Version 0.5.0 (in development)
 ==============================
+PyUnity is a Python implementation of the
+Unity Engine, written in C++. This is just
+a fun project and many features have been
+taken out to make it as easy as possible
+to create a scene and run it.
 
-A Python implementation of the Unity Engine
-that supports different types of windows.
-Still in development.
+Installing
+----------
+To install PyUnity for Linux distributions
+based on Ubuntu or Debian, use::
 
-Installation
-------------
-The first step in using PyUnity is always
-installing it. To install pyunity, simply run
+    > pip3 install pyunity
 
-    pip install pyunity
+To install PyUnity for other operating systems,
+use pip::
+
+    > pip install pyunity
+
+Alternatively, you can clone the repository
+`here <https://github.com/rayzchen/pyunity>`_
+to build the package from source. Then use
+``setup.py`` to build. Note that it will install
+Cython to compile.
+
+    > python setup.py install
+
+Its only dependencies are PyOpenGL, Pygame,
+GLFW, Pillow and PyGLM.
 
 Importing
 ---------
@@ -26,11 +43,10 @@ PYUNITY_DEBUG_MODE environment variable to ``"0"``.
 This is the output with debugging::
 
     Loaded config
-    Trying FreeGLUT as a window provider
-    FreeGLUT doesn't work, trying GLFW
+    Trying GLFW as a window provider
     GLFW doesn't work, trying Pygame
     Using window provider Pygame
-    Loaded PyUnity version 0.3.1
+    Loaded PyUnity version 0.5.0
 
 If debugging is off, there is no output:
 
@@ -55,7 +71,7 @@ Finally, add a cube at the origin:
     >>> cube = GameObject("Cube")
     >>> renderer = cube.AddComponent(MeshRenderer)
     >>> renderer.mesh = Mesh.cube(2)
-    >>> renderer.mat = Material((255, 0, 0))
+    >>> renderer.mat = Material(Color(255, 0, 0))
     >>> scene.Add(cube)
 
 To see what you have added to the scene, call ``scene.List()``:
@@ -113,7 +129,7 @@ To run an example, import it like so:
     FreeGLUT doesn't work, trying GLFW
     GLFW doesn't work, trying Pygame
     Using window provider Pygame
-    Loaded PyUnity version 0.3.1
+    Loaded PyUnity version 0.5.0
     >>> main()
 
 Or from the command line::
@@ -121,41 +137,46 @@ Or from the command line::
     > python -m pyunity 1
 
 The ``1`` just means to load example 1, and there
-are 8 examples. To load all examples one by
+are 9 examples. To load all examples one by
 one, do not specify a number. If you want to
 contribute an example, then please
 create a new pull request.
 
 """
 
+from . import logger as Logger  # lgtm[py/import-own-module]
 from .audio import *
 from .core import *
-from . import loader  # lgtm[py/import-own-module]
+from .script import Behaviour
+from . import loader as Loader  # lgtm[py/import-own-module]
 from . import input as Input  # lgtm[py/import-own-module]
 from .input import KeyCode
 from .physics import *
 from .errors import *
-from .scene import SceneManager
+from .files import *
+from .scenes import sceneManager as SceneManager
 from .quaternion import Quaternion
 from .vector3 import Vector3
 from .meshes import Mesh
-import os
-__version__ = "0.3.1"
-__copyright__ = "Copyright 2020 Ray Chen"
+
+__version__ = "0.5.0"
+__copyright__ = "Copyright 2020-2021 Ray Chen"
 __email__ = "tankimarshal2@gmail.com"
 __license__ = "MIT License"
 __summary__ = "A Python implementation of the Unity Engine that supports different types of windows."
 __title__ = "pyunity"
 __uri__ = "https://pyunity.readthedocs.io/en/latest/"
 
-from . import audio, core, physics, errors
+from . import audio, core, physics, errors, files
 __all__ = ["__version__", "Vector3", "Quaternion",
-           "SceneManager", "Mesh", "loader",
-           "Input", "KeyCode"]
+           "SceneManager", "Mesh", "Loader",
+           "Input", "KeyCode", "Logger",
+           "Behaviour"]
 __all__.extend(audio.__all__)
 __all__.extend(core.__all__)
 __all__.extend(physics.__all__)
 __all__.extend(errors.__all__)
+__all__.extend(files.__all__)
 
-if os.environ["PYUNITY_DEBUG_MODE"] == "1":
-    print("Loaded PyUnity version %s" % __version__)
+Logger.LogLine(Logger.DEBUG, "Loaded PyUnity version %s" % __version__)
+Logger.LogSpecial(Logger.INFO, Logger.RUNNING_TIME)
