@@ -6,7 +6,7 @@ class Rotator(Behaviour):
         self.transform.eulerAngles += Vector3(0, 90, 135) * dt
 
 def main():
-    mesh = loader.LoadMesh(os.path.join(
+    mesh = Loader.LoadMesh(os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "cube.mesh"))
 
     scene = SceneManager.AddScene("Scene")
@@ -17,7 +17,7 @@ def main():
     cube.AddComponent(Rotator)
     renderer = cube.AddComponent(MeshRenderer)
     renderer.mesh = mesh
-    renderer.mat = Material((255, 0, 0))
+    renderer.mat = Material(Color(255, 0, 0))
     scene.Add(cube)
 
     scene.List()
